summaryrefslogtreecommitdiff
path: root/worker/tests/http.rb
diff options
context:
space:
mode:
Diffstat (limited to 'worker/tests/http.rb')
-rwxr-xr-xworker/tests/http.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/worker/tests/http.rb b/worker/tests/http.rb
index bfd1820..d1faa4d 100755
--- a/worker/tests/http.rb
+++ b/worker/tests/http.rb
@@ -36,7 +36,7 @@ class HTTPTest
#
# Return "false" on failure.
#
# If the test fails the details should be retrieved from "get_details".
#
def run_test
@@ -92,7 +92,7 @@ class HTTPTest
#
# Return the error text for why this test failed.
#
- def get_details
+ def error
return @error
end
@@ -36,7 +36,7 @@ class HTTPTest
# Return "false" on failure.
#
- # If the test fails the details should be retrieved from "get_details".
+ # If the test fails the details should be retrieved from "error()".
#
def run_test